import axios from 'axios';
import type {
  OptionItem,
  TaskListPageParam,
  TaskListPageRes,
  TaskItemDetail,
  TaskRuleUpdateParams,
  TaskTimeUpdateParams,
  TaskNoticeUpdateParams,
  OrderRecordListPageRes,
  OrderRecordListPageParam,
  StudentExportListPageRes,
} from './types/order';
import { AbleParams } from './types/common';

// common
export function taskQuery(): Promise<OptionItem[]> {
  return axios.post('/api/apply/task/list', {});
}
export function teachingQuery(): Promise<OptionItem[]> {
  return axios.post('/api/apply/teaching/list', {});
}
export function agentQuery(teachingId: string): Promise<OptionItem[]> {
  return axios.post(
    '/api/apply/agent/list',
    {},
    { params: { id: teachingId } }
  );
}

// task-manage
export function taskListPage(
  params: TaskListPageParam
): Promise<TaskListPageRes> {
  return axios.post('/api/admin/apply/task/page', {}, { params });
}
export function taskDetailInfo(id: string): Promise<TaskItemDetail> {
  return axios.post('/api/admin/apply/task/find', {}, { params: { id } });
}
export function updateTaskRule(
  datas: TaskRuleUpdateParams
): Promise<{ id: string }> {
  return axios.post('/api/admin/apply/task/rule/save', datas);
}
export function updateTaskTime(
  datas: TaskTimeUpdateParams
): Promise<{ id: string }> {
  return axios.post('/api/admin/apply/task/time/save', datas);
}
export function updateTaskNotice(
  datas: TaskNoticeUpdateParams
): Promise<{ id: string }> {
  return axios.post('/api/admin/apply/task/notice/save', datas);
}
export function ableTask(params: AbleParams): Promise<boolean> {
  return axios.post('/api/admin/apply/task/enable', {}, { params });
}

// 考生信息导入
// 考生信息导入分页
export function studentImportListPage(): Promise<StudentExportListPageRes> {
  return axios.post('/api/admin/std/import/page', {});
}
// 考生信息导入-导入模板下载
export function studentInfoTemplate(): Promise<Blob> {
  return axios.post(
    '/api/admin/std/import/template',
    {},
    {
      responseType: 'blob',
    }
  );
}

// 预约名单
// 预约名单详情分页
export function orderRecordListPage(
  params: OrderRecordListPageParam
): Promise<OrderRecordListPageRes> {
  return axios.post('/api/apply/std/page', params);
}
// 预约名单详情-取消预约
export function orderRecordCancel(id: number): Promise<boolean> {
  return axios.post('/api/apply/std/cancel', {}, { params: { id } });
}
// 预约名单详情-一键自动分配
export function orderRecordAutoAssign(params: {
  taskId: number;
}): Promise<boolean> {
  return axios.post('/api/apply/std/auto/assign', {}, { params });
}
// 预约名单详情-导入模板下载
export function orderRecordTemplate(): Promise<Blob> {
  return axios.post(
    '/api/apply/imp/template',
    {},
    {
      responseType: 'blob',
    }
  );
}
// 预约名单详情-打印签到表
export function orderRecordPrint(params: {
  teachingId?: number;
}): Promise<Blob> {
  return axios.post(
    '/api/apply/std/auto/sign/in/print',
    {},
    {
      responseType: 'blob',
      params,
    }
  );
}
