import { defineStore } from 'pinia';
import { omit } from 'lodash';
import { menus } from './menuData';

import { AppState, AppMenuItem, UserMenuItem } from './types';
import { RoleType } from '../../../constants/enumerate';

function transformMenu(list: typeof menus): UserMenuItem[] {
  return list.map((menu) => omit(menu, ['roles']));
}

function getMenu(privilegeData: UserMenuItem[]): {
  menuList: AppMenuItem[];
  validRoutes: string[];
} {
  const getChildren = (id) => {
    return privilegeData
      .filter((item) => item.parentId === id)
      .map((item) => {
        return { ...item };
      });
  };
  const menuList = getChildren('-1');
  const validRoutes = [];
  const toTree = (data: PrivilegeItem[]) => {
    data.forEach((menu) => {
      const children = getChildren(menu.id);
      if (children.length) {
        menu.children = children;
        toTree(menu.children);
      } else {
        validRoutes.push(menu.url);
      }
    });
  };
  toTree(menuList);

  return { menuList, validRoutes };
}

const useAppStore = defineStore('app', {
  state: (): AppState => ({
    version: '',
    appMenus: [],
    privilegeList: [],
    validRoutes: [],
    breadcrumbs: [],
  }),

  getters: {
    appInfo(state: AppState): AppState {
      return { ...state };
    },
  },

  actions: {
    resetInfo() {
      this.$reset();
    },
    setInfo(partial: Partial<AppState>) {
      this.$patch(partial);
    },
    fetchServerMenu(type: RoleType) {
      const userMenus = menus.filter(
        (menu) => !menu.roles || menu.roles.includes(type)
      );
      const { menuList, validRoutes } = getMenu(transformMenu(userMenus));
      this.appMenus = menuList;
      this.validRoutes = validRoutes;
    },
    getMenuFirstRouter() {
      let firstRouteName = '';
      let menu = this.appMenus[0];

      while (menu) {
        firstRouteName = menu.url;
        menu = menu.children && menu.children[0];
      }

      return { name: firstRouteName };
    },
  },
  persist: {
    storage: sessionStorage,
  },
});

export default useAppStore;
